@@ -1,10 +1,7 @@
 /*
-  Copyright (c) 2007 Paolo Capriotti <p.capriotti@gmail.com>
-            
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-FileCopyrightText: 2007 Paolo Capriotti <p.capriotti@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "aientity.h"
@@ -63,19 +60,19 @@ void AIEntity::notify(Sea::Player player, const Coord& c, const HitInfo& info)
 
 void AIEntity::notifyGameOptions()
 {
-    emit gameOptionsInterchanged();
+    Q_EMIT gameOptionsInterchanged();
 }
 
 void AIEntity::start()
 {
-    emit ready(m_player);
+    Q_EMIT ready(m_player);
 }
 
 void AIEntity::startPlacing()
 {
     m_seaview->setStatus(Sea::PLACING_SHIPS);
     m_ai->setShips();
-    emit shipsPlaced();
+    Q_EMIT shipsPlaced();
 }
 
 void AIEntity::startPlaying()
@@ -99,7 +96,7 @@ void AIEntity::getShoot()
     if (m_sea->turn() == m_player) {
         Coord c = m_ai->getMove();
         
-        emit shoot(m_player, c);
+        Q_EMIT shoot(m_player, c);
     }
 }
 
